References
==========

.. [chaudhuri93] B. B. Chaudhuri und P. Kundu. "Optimum circular fit
    to weighted data in multi-dimensional space". Pattern
    Recognition Letters 14.1 (1993), S. 1–6

.. [chalmecalvet2013] R. Chalme-Calvet, M. de Naurois, J.-P. Tavernet
    "Muon efficiency of the H.E.S.S" telescope. AtmoHEAD Workshop, 2013.
    https://arxiv.org/pdf/1403.4550.pdf

.. [denaurois2009] M de Naurois, L. Roland
    "A high performance likelihood reconstruction of gamma-rays for imaging
    atmospheric Cherenkov telescopes". Astroparticle Physics 32.5, (2009)
    https://arxiv.org/abs/0907.2610

.. [temme2016] Temme T.F., "On the hunt for photons: analysis of Crab Nebula
    data obtainedby the first G-APD Cherenkov telescope" 2016
    DOI: 10.17877/DE290R-17773

.. [factcleaning] https://github.com/fact-project/fact-tools

.. [ctatopleveldatamodel] K. Kosack et al, "Top-level Data Model", CTAO Computing
    Department Internal Documentation, CTA-SPE-OSO-000000-0001, v1A.

.. [lts_regression] P. J. Rousseeuw, K. van Driessen, "Computing LTS Regression for Large Data Sets",
    Data Mining and Knowledge Discovery, 12, 29-45, DOI: 10.1007/s10618-005-0024-4

.. [hillas_uncertainties] W. Wittek, "Image Parameters", MAGIC-TDAS internal note 02-03, (2002). 
